main > .container {
  padding: 30px 15px 0;
}

.splash img {
    width: 70%;
}

.splash {
    background: #212651;
    background-image: url("/static/images/network.png"); /* fallback */ 
    background-repeat: no-repeat;
    background-position: bottom;
    padding-bottom: 300px; 
}

a.custom-card,
a.custom-card:hover {
  color: inherit;
  text-decoration: none;
}

.cards { 
    transition: all 0.2s ease;
    cursor: pointer;
}

.cards:hover { 
    box-shadow: 5px 6px 6px 2px #e9ecef; 
    background: #eeeeee;
}
/* .footer { */
/*     background-color: rgb(38, 39, 39) !important; */
/*     color: #FFFFFF; */
/*     padding-top: 20px; */
/*     margin-top: 20px; */
/* } */
/*  */
/* .footer li { */
/*     list-style: none; */
/*     position: relative; */
/*     margin-bottom: 0; */
/*     padding: 0.2em; */
/* } */
/*  */
/* .footer span { */
/*     margin-right: 5px; */
/* } */
/*  */
/* .footer a { */
/*     text-decoration: none; */
/* } */
/*  */
/* .footer img { */
/*     width: 100px; */
/* } */


/*
 * Sidebar
 */

.sidebar {
  position: fixed;
  top: 0;
  /* rtl:raw:
  right: 0;
  */
  bottom: 0;
  /* rtl:remove */
  left: 0;
  z-index: 100; /* Behind the navbar */
  padding: 50px 0 0; /* Height of navbar */
  box-shadow: inset -1px 0 0 rgba(0, 0, 0, .1);
}

@media (max-width: 767.98px) {
  .sidebar {
    top: 5rem;
  }
}

.sidebar-sticky {
  position: relative;
  top: 0;
  height: calc(100vh - 50px);
  padding-top: .5rem;
  overflow-x: hidden;
  overflow-y: auto; /* Scrollable contents if viewport is shorter than content. */
}

.sidebar .nav-link {
  font-weight: 500;
  color: #dddddd; 
}

.sidebar .nav-link .feather {
  margin-right: 4px;
  color: #727272;
}

.sidebar .nav-link.active {
  color: #007bff;
}

.sidebar .nav-link:hover .feather,
.sidebar .nav-link.active .feather {
  color: inherit;
}

.sidebar-heading {
  font-size: 1.2rem;
  text-transform: uppercase;
  font-weight: bold;
}

/*
 * Navbar
 */

.navbar-brand {
  padding-top: .75rem;
  padding-bottom: .75rem;
  font-size: 1rem;
}

