{% for category, message in get_flashed_messages() %}
{% if category == 'message' %}
    {% set category = 'info' %}
{% endif %}
<div class="alert alert-{{category}} alert-dismissible mb-4 mt-4">
    <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close"></button>
    {{ message }}
</div>
{% endfor %}
