<footer class="footer bg-dark text-white pt-2 pb-0 mt-auto ">
    <div class="container">
        <div class="row">
            <div class="col-md-4 my-0">
                <span class="text-muted">
                © 2022 DEEP-Hybrid-DataCloud consortium members.
                </span>
                <p class="text-muted" style="font-size:10px;">This project has received funding from the European Union’s Horizon 2020 research and innovation programme under grant agreement No 777435.</p>
            </div>
            <div class="col-md-6 my-0">
                <p>
                    <img src="https://deep-hybrid-datacloud.eu/wp-content/uploads/sites/2/2018/01/logo_EUC-1.png" height=50/>
                </p>
            </div>
            <div class="col-md-2 mt-4" style="display:flex;justify-content:space-around;color:white">
                <a href="https://twitter.com/DEEP_eu" target="_blank" alt="Twitter" title="Twitter" class="link-secondary">
                    <i class="fab fa-twitter fa-fw"></i>
                </a>
                <a href="https://www.linkedin.com/groups/12093546" target="_blank" alt="Linkedin" title="Linkedin" class="link-secondary">
                    <i class="fab fa-linkedin fa-fw"></i>
                </a>
                <a href="https://github.com/deephdc/" target="_blank" alt="Github" title="Github" class="link-secondary">
                    <i class="fab fa-github fa-fw"></i>
                </a>
                <a href="https://hub.docker.com/u/deephdc/" target="_blank" alt="DockerHub" title="DockerHub" class="link-secondary">
                    <i class="fab fa-docker fa-fw"></i>
                </a>
                <a href="https://www.researchgate.net/project/DEEP-Hybrid-DataCloud" target="_blank" alt="ResearchGate" title="ResearchGate" class="link-secondary">
                    <i class="fab fa-researchgate fa-fw"></i>
                </a>
                <a href="https://docs.deep-hybrid-datacloud.eu/" target="_blank" alt="Documentation" title="Documentation" class="link-secondary">
                    <i class="fa fa-book fa-fw"></i>
                </a>
            </div>
        </div>
    </div>
</footer>
