{% extends "base.html" %}

{% block subtitle %}
{% if current_user.authenticated %}
 - Overview
 {% else %}
 - Login
 {% endif %}
{% endblock %}

{% block content %}
    {% if current_user.authenticated %}
    {% include "overview.html" %}
    {% else %}
    {% include "login.html" %}
    {% endif %}
{% endblock %}
