{% extends "base.html" %}

{% block content %}

<div class="d-flex justify-content-between flex-wrap flex-md-nowrap align-items-center pt-3 pb-2 mb-3 border-bottom">
    <h2>TOSCA template</h2>
</div>

<div class="container">

    <br>

    <div class="card shadow mb-4">
        <div class="card-header py-3">
          <div class="row">
            <div class="col-md-6">
              <!-- Title -->
              <h4 class="font-weight-bold text-primary">Template</h4>
            </div>
            <div class="col-md-6 text-right">
              <!-- Button -->
              <button type=button class="btn btn-small btn-outline-secondary" onclick="history.back()"><span class="fas fa-arrow-left mr-2"></span> Back</button>
            </div>
          </div> <!-- / .row -->
        </div>

        <div class="card-body">
          <pre>{{ template | safe }}</pre>
        </div>
    </div>
</div>
{% endblock %}
