{% block content %}


<main class="flex-shrink-0 splash">
<div class="container mb-4">
    <div class="login-header px-3 py-3 pt-md-5 pb-md-4 mx-auto text-center text-white">
        <h1 class="display-4">DEEP Dashboard</h1>
        <p class="lead">A comprehensive platform for machine learning, deep
        learning and artificial intelligence in the European Open Science
        Cloud. Developing, training, sharing and deploying your model has never
        been easier.</p>
    </div>

    {% include 'flashed_messages.html' %} 

    <div class="row justify-content-center">
        <div class="col-5">
            <div class="card">
               <h4 class="card-header">Log In</h4>
               <div class="card-body">
                   <div class="row">
                        <div class="col-3 py-3">
                            <img src="{{ url('static', filename='images/deep-cloud.png') }}"></img>
                        </div>
                       <div class="col">
                           <p>
                           In order to access the DEEP Dashboard you need to be
                           registered with the DEEP IAM. No account?
                           Please refer to the <a
                               href="https://docs.deep-hybrid-datacloud.eu/">documentation</a>
                           for more information.
                           </p>
                           <p>
                           <a class="btn btn-primary" role="button" href="{{ url("login") }}">Login with the DEEP IAM &raquo;</a>
                           </p>
                        </div>
                   </div>
               </div>
            </div>
        </div>
    </div>
</div>
</main>
{# 
    <div class="row pt-5">
        <div class="col-7">
        <div>
            <p>
            Welcome to the 
            <a href="https://deep-hybrid-datacloud.eu/">DEEP-Hybrid-DataCloud</a>
            training facility Dashboard. From this portal you will be able to
            train any model from the 
            <a href="https://marketplace.deep-hybrid-datacloud.eu"/>DEEP Marketplace</a> or your own built model.
            </p>
            <p>
            Please refer to the <a href="https://docs.deep-hybrid-datacloud.eu/">documentation</a> for more information.
            </p>
            <p>
            <a class="btn btn-primary btn-lg" role="button" href="{{ url("login") }}">Login with the DEEP IAM &raquo;</a>
            </p>
        </div>
    </div>
    <div class="col pt-5">
        <img src="{{ url('static', filename='images/deep-cloud.png') }}"></img>
    </div>
</div>
</div>
#}
{% endblock %}
